@@ -1,8 +1,8 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: urls.py 12425 2020-07-26 06:31:20Z Bear $
+# $Id: urls.py 12428 2020-07-26 13:13:50Z Bear $
 #
-# Copyright (c) 2013 Nuwa Information Co., Ltd, All Rights Reserved.
+# Copyright (c) 2020 Nuwa Information Co., Ltd, All Rights Reserved.
 #
 # Licensed under the Proprietary License,
 # you may not use this file except in compliance with the License.
@@ -12,15 +12,14 @@
 # limitations under the License.
 #
 # $Author: Bear $
-# $Date: 2020-07-26 14:31:20 +0800 (週日, 26 七月 2020) $
-# $Revision: 12425 $
+# $Date: 2020-07-26 22:13:50 +0900 (週日, 26 七月 2020) $
+# $Revision: 12428 $
 
-from django.conf.urls import include, url
+from django.conf.urls import url
 # Required import for 404 handle.
 from django.conf.urls import handler404
 # Required import for 500 handle.
 from django.conf.urls import handler500
-from django.views.generic.base import TemplateView as direct_to_template
 
 from django.contrib import admin
 admin.autodiscover()
@@ -35,7 +34,5 @@ import Iuno
 Iuno.attachURLs(settings, urlpatterns)
 
 urlpatterns += patterns('',
-    (r'^i18n/', include('Iuppiter.i18n.urls')),
-    (r'^admin/', admin.site.urls),
+    url(r'^admin/', admin.site.urls),
 )
-
