@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12628 2020-11-26 12:39:59Z Lavender $
+# $Id: __init__.py 12638 2020-12-17 07:19:51Z Lavender $
 #
 # Copyright (c) 2016 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,29 +12,106 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-11-26 21:39:59 +0900 (週四, 26 十一月 2020) $
-# $Revision: 12628 $
+# $Date: 2020-12-17 16:19:51 +0900 (週四, 17 十二月 2020) $
+# $Revision: 12638 $
 
+import random
+import requests
 import collections
 import json
 
 import requests
 
+from django.template import Context, Template
+from django.conf import settings
 from six.moves import urllib_parse, urllib_request, urllib_error
 
 from Iuno import require
 from Iuppiter.Encoding import utf8
-from Iuppiter.DjangoUtil import extendInstalledApps
+from Iuppiter.DjangoUtil import extendInstalledApps, patterns
 
 def attachSettings(settingsLocals, backends, preferred, config):
-    # IUNO_CLOUD_SMS_ADMIN = True 時加入
-    extendInstalledApps(settingsLocals, (
-        'Iuno.cloud.sms',
-    ))
+    if "IUNO_CLOUD_SMS_ADMIN" in settingsLocals:
+        extendInstalledApps(settingsLocals, (
+            'Iuno.cloud.sms',
+        ))
+    else:
+        require("IUNO_CLOUD_SMS_CLIENT_TOKEN", settingsLocals) 
+        
+DEFAULT_PREFIX_COUNT = 4
+DEFAULT_CODE_COUNT = 6
+DEFAULT_TEMPLATE = ("{%if site %}[{{ site }}]{% endif %} "
+    "您好，驗證碼為6位數字: {{ code }}，請確認網頁識別碼 {{ prefix }}")
+
+DEFAUTL_API_URL = "https://api.nuwainfo.com/sms/api/send/"
+
+def verify(phone, template=None, prefixCount=DEFAULT_PREFIX_COUNT, codeCount=DEFAULT_CODE_COUNT):
+    prefix = "".join([random.choice('ABCDEFGHIJKLMNOPQRSTUVWXYZ') for i in range(prefixCount)])
+    code = "".join([random.choice('0123456789') for i in range(codeCount)])
+    
+    # 在 __init__.py 內不能先 import model，因此在這裡 import 
+    from django.contrib.sites.models import Site
+    
+    if template:
+        message = Template(template)
+    else:
+        message = Template(DEFAULT_TEMPLATE)
+    message = message.render(Context({
+        "prefix": prefix,
+        "code": code,
+        "site": Site.objects.get_current().name,
+    }))
+    
+    payload = {
+        "phone": phone,
+        "message": message,
+        "token": settings.IUNO_CLOUD_SMS_CLIENT_TOKEN,
+    }
+    if hasattr(settings, "IUNO_CLOUD_SMS_CLIENT_URL"):
+        url = settings.IUNO_CLOUD_SMS_CLIENT_URL
+    else:
+        url = DEFAUTL_API_URL
+        
+    response = requests.post(url, payload) 
+    data = json.loads(response.text)
+        
+    if data.get("stats"):
+        data.update({
+            "prefix": prefix,
+            "code": code,
+        })
+    data.update({
+        "prefix": prefix,
+        "code": code,
+    })
+    
+    return data
+    
+def attachURLs(settings, urlpatterns):
+    from django.conf.urls import url
+    from Iuno.cloud.sms.views import callAPISMS, sendSMSAuthentication
+    
+    addCloudSMSAPIUrl = False
+    if hasattr(settings ,'IUNO_CLOUD_SMS_ADMIN'):
+        if settings.IUNO_CLOUD_SMS_ADMIN:
+            if hasattr(settings ,'IUNO_CLOUD_SMS_ADMIN'):
+                services = settings.IUNO_CLOUD_SERVICES
+                if 'sms' in services:
+                    addCloudSMSAPIUrl = True
+            else:
+                addCloudSMSAPIUrl = True
+                
+    if addCloudSMSAPIUrl:
+        urlpatterns += patterns('',
+            url(r'^sms/api/send/', callAPISMS, name='callAPISMS'),
+        )
+        
+    if hasattr(settings ,  'IUNO_CLOUD_SMS_MEDIATOR'):
+        urlpatterns += patterns('',
+            url(r'^sms/authentication/send/', 
+                sendSMSAuthentication, name='sendSMSAuthentication'),
+        )
     
-    if "IUNO_CLOUD_SMS_CLIENT_ENABLE" in settingsLocals: # 這個不用
-        require("IUNO_CLOUD_SMS_CLIENT_URL", settingsLocals) # 這個預設 api.nuwainfo.com
-        require("IUNO_CLOUD_SMS_CLIENT_TOKEN", settingsLocals) # 這個 require，如果 IUNO_CLOUD_SMS_ADMIN = True 則不用
 
 class SMS(object):
 
@@ -141,3 +218,5 @@ class SMS(object):
                 break
         
         self.result = result
+        
+
