@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12541 2020-10-07 17:14:18Z Lavender $
+# $Id: __init__.py 12555 2020-10-15 08:37:39Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-10-08 02:14:18 +0900 (週四, 08 十月 2020) $
-# $Revision: 12541 $
+# $Date: 2020-10-15 17:37:39 +0900 (週四, 15 十月 2020) $
+# $Revision: 12555 $
 
 import os
 import re
@@ -216,7 +216,7 @@ def attachSettings(settingsDict, enablePaypal=False):
     # 付款表單時，先記錄哪個 basket 對哪個 sessionKey，當付款回來後將 request.session
     # 拿回來
     ADDING_MIDDLEWARE_CLASSES2 = (
-        'Iuno.shop.middleware.PaymentSessionMiddleware',
+        'Iuno.shop.Middleware.PaymentSessionMiddleware',
     )
                             
     extendMiddlewareClasses(settingsDict, ADDING_MIDDLEWARE_CLASSES2,
