@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: forms.py 12182 2020-05-07 07:28:10Z Lavender $
+# $Id: forms.py 12301 2020-06-03 06:08:57Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-05-07 16:28:10 +0900 (週四, 07 五月 2020) $
-# $Revision: 12182 $
+# $Date: 2020-06-03 15:08:57 +0900 (週三, 03 六月 2020) $
+# $Revision: 12301 $
 
 import os
 import re
@@ -234,27 +234,37 @@ def format_object(self, obj):
 catalogueViews.ProductLookupView.lookup_filter = lookup_filter
 catalogueViews.ProductLookupView.format_object = format_object
 
+AttributeOption = get_model('catalogue', 'AttributeOption')
+
 # https://code.nuwainfo.com/trac/Mercurius/ticket/3272#ticket
 def process_all_forms(self, form):
     if self.creating and form.is_valid():
         self.object = form.save(commit=False)
     
+    groupId = None
     postCopy = self.request.POST.copy()
     for k, v in postCopy.items():
         if 'options-' in k and '-option' in k and v:
-            postCopy[k] = u"%s" % hashlib.md5(
-                str("%s%s" % (v, datetime.datetime.now())).encode()).hexdigest()
+            postCopy[k.replace('-option', '-id')] = ''
+            # postCopy[k] = u"%s" % hashlib.md5(
+                # str("%s%s" % (v, datetime.datetime.now())).encode()).hexdigest()
+            groupId = postCopy[k.replace('-option', '-group')]
+    postCopy['options-INITIAL_FORMS'] = '0'
+            
+    if groupId:
+        AttributeOption.objects.filter(group=groupId).delete()
     
     attribute_option_formset = self.attribute_option_formset(
         self.request.POST, self.request.FILES, instance=self.object)
     attribute_option_formset2 = self.attribute_option_formset(
         postCopy, self.request.FILES, instance=self.object)
 
+    # is_valid = form.is_valid() and attribute_option_formset2.is_valid() and attribute_option_formset.is_valid()
     is_valid = form.is_valid() and attribute_option_formset2.is_valid()
-
+    
     if is_valid:
-        attribute_option_formset2.save()
-        return self.forms_valid(form, attribute_option_formset)
+        # attribute_option_formset2.save()
+        return self.forms_valid(form, attribute_option_formset2)
     else:
         return self.forms_invalid(form, attribute_option_formset)
         
