@@ -17,6 +17,8 @@
 
 import os
 
+import jieba
+
 from django import template
 from django.utils.safestring import mark_safe
 from django.conf import settings
@@ -61,4 +63,10 @@ def getLineAttributeValue(context, attribute):
         val = attribute.value
         
     
-    return val
\ No newline at end of file
+    return val
+    
+@register.filter(name='jiebaCut')
+def jiebaCut(value):
+    words = list(jieba.cut(value, cut_all=False))
+    data = " ".join(words)
+    return data
\ No newline at end of file
