@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 12541 2020-10-07 17:14:18Z Lavender $
+# $Id: views.py 12656 2020-12-24 06:28:00Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2020-10-08 02:14:18 +0900 (週四, 08 十月 2020) $
-# $Revision: 12541 $ 
+# $Date: 2020-12-24 15:28:00 +0900 (週四, 24 十二月 2020) $
+# $Revision: 12656 $ 
 
 import json
 import logging
@@ -387,13 +387,14 @@ from des.models import DynamicEmailConfiguration
 from django.contrib.sites.models import Site
 from oscar.apps.order.processing import EventHandler
 
-def sendOrderEmail(order, subjectTemp, htmlTemp, txtTemp):
+def sendOrderEmail(order, subjectTemp, htmlTemp, txtTemp, context={}):
     try:
         temp = get_template(subjectTemp)
         ctx = {
             "order": order,
             "site": Site.objects.get(id=settings.SITE_ID)
         }
+        ctx.update(context)
         subject = temp.render(ctx)
         
         temp = get_template(htmlTemp)
@@ -1129,11 +1130,15 @@ class SuccessResponseView2(_PaymentDetailsView):
                 'check_user_email_is_captured',
             ]
         return conditions
-
+        
     def post(self, request, *args, **kwargs):
         # apiName
         self.apiName = kwargs['name']
         
+        msg = "%s: %s" % (_('User'), request.user.username)
+        
+        sandMessageToAdmin(_("User checkout notification"), msg)
+        
         if not self.apiName in [
             SPGATEWAY, ALLPAY, ECPAY, CATHAYBK_CREDIT, 
             CATHAYBK_CUP, ECPAY_MAP, ECPAY_LOGISTIC, ATM]:
